API Reference
=============

Below user API and internal API pages show already-implemented Uxarray functionality.
You can also check the draft `Uxarray API
<https://github.com/UXARRAY/uxarray/blob/main/docs/user_api/uxarray_api.md>`_
documentation to see the tentative whole API and let us know if you have any feedback!

.. toctree::
   :maxdepth: 2

   user_api/index.rst
   internal_api/index.rst
